@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -653,6 +653,9 @@ cEncoder::cEncoder( int e, int f )
 
 cEncoder::~cEncoder() 
 {
+    sack_type::iterator itr;
+    for( itr = m_encodings.begin(); itr != m_encodings.end(); ++itr)
+        delete *itr;
 }
 
 bool cEncoder::RoundTrip() const
