@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -78,7 +78,7 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <time.h>
-#if defined(HAVE_MALLOC_H)
+#if HAVE_MALLOC_H && !IS_AROS
 #include <malloc.h>
 #endif
 #include <string.h>
@@ -94,6 +94,13 @@
 #include <assert.h>
 #include "msystem.h"
 
+#if IS_REDOX
+#define setuid(x) sleep(0) 
+#define setgid(x) sleep(0)
+#endif
+ 
+
+
 /*
  * signal type
  */
