@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -274,7 +274,7 @@ iTypedSerializable* cSerializerImpl::ReadObjectDynCreate()
             // unable to find the creation function...
             d.TraceError("Unable to find creation function for non-ref counted object %d\n", crc);
             TOSTRINGSTREAM str;
-            #ifdef _DEBUG
+            #ifdef DEBUG
             // Let's only report the actual crc in debug mode
             str << (int32)crc << std::ends;
             #endif
