@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -267,7 +267,7 @@ void cNullSignature::Read(iSerializer* pSerializer, int32 version)
     if (version > Version())
         ThrowAndAssert(eSerializerVersionMismatch(_T("Null Signature Read")));
 
-#ifdef _DEBUG
+#ifdef DEBUG
     int16 ret;
     pSerializer->ReadInt16(ret);
     ASSERT(ret == 123);
@@ -276,7 +276,7 @@ void cNullSignature::Read(iSerializer* pSerializer, int32 version)
 
 void cNullSignature::Write(iSerializer* pSerializer) const
 {
-#ifdef _DEBUG
+#ifdef DEBUG
     pSerializer->WriteInt16(123);
 #endif
 }
