@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -324,7 +324,7 @@ void cIntegrityCheck::ProcessDir( cDbDataSourceIter dbIter, iFCODataSourceIter*
         return;
     }
 
-#ifdef _DEBUG
+#ifdef DEBUG
     if( dbIter.Done() )
     {
         d.TraceDebug( "Processing directory %s\n", pIter->GetParentName().AsString().c_str() );
