@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -361,8 +361,8 @@ private:
    cTWModeHelp_i* mpData;  
 };
 
-//These two modes are invisible if _DEBUG_DB is not defined.
-#ifdef _DEBUG_DB
+//These two modes are invisible if DEBUG is not defined.
+#ifdef DEBUG
 
 ///////////////////////////////////////////////////////////////////////////////
 // Explore Db
@@ -404,7 +404,7 @@ private:
    cTWModeDebugDb_i* mpData;  
 };
 
-#endif //_DEBUG_DB
+#endif //DEBUG
 
 ///////////////////////////////////////////////////////////////////////////////
 // Version Mode
