@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -722,7 +722,7 @@ void cFCOReport::AddChangedFCO(const cFCOReportSpecIter& iter, const iFCO* pOldF
 
     // make some assertions about the iterator
 
-    #ifdef _DEBUG
+    #ifdef DEBUG
     // make sure iter points to one of our spec lists
     cFCOReport_i::GenreSpecList::iterator genreIter;
     for (genreIter = mpData->mGenreList.begin(); ; ++genreIter)
