@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -42,7 +42,7 @@
 
 #define UNICODE_STR _T("")
 
-#ifdef _DEBUG
+#ifdef DEBUG
 #   define DEBUG_STR _T("d")
 #else
 #   define DEBUG_STR _T("")
@@ -111,7 +111,7 @@ TSS_BeginStringtable( cTW )
     TSS_StringEntry( tw::STR_NEWLINE,               _T("\n")),
     TSS_StringEntry( tw::STR_ERR_TWCFG_CANT_READ,   _T("Configuration file could not be read.")),
     TSS_StringEntry( tw::STR_ERR_NO_MODE,           _T("No mode specified.")),
-    TSS_StringEntry( tw::STR_UNKOWN_MODE_SPECIFIED, _T("Unknown mode specified: ")),
+    TSS_StringEntry( tw::STR_UNKNOWN_MODE_SPECIFIED, _T("Unknown mode specified: ")),
     TSS_StringEntry( tw::STR_ERR2_BAD_MODE_SWITCH,  _T("Unrecognized mode: ")),
 
     TSS_StringEntry( tw::STR_OPEN_POLICY_FILE,      _T("Opening policy file: ")),
@@ -249,5 +249,5 @@ TSS_BeginStringtable( cTW )
 TSS_EndStringtable( cTW )
 
 
-// eof: twstrings.cpp
+
 
