@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -116,7 +116,10 @@ cCryptoArchive::~cCryptoArchive()
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_UNKNOWN || mAction == MA_FINISHED || mAction == MA_READING);
         // check we did not leave a buffer unwritten
-    
+
+    Finish();
+
+    // Finish() normally zeroes these out, but hey.
     delete mpDeflator;
     delete mpInflator;
 }
