@@ -1,6 +1,6 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2017 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
 // 
@@ -33,31 +33,30 @@
 // genre_t.cpp
 //
 
-#include <typeinfo>
-
 #include "fco/stdfco.h"
 #include "fco/genreswitcher.h"
 #include "twtest/test.h"
 #include "fs/fs.h"
 
-#include "fs/fsfactory.h"
-
-void TestGenreSwitcher()
+void TestGenre()
 {
-    cDebug d("TestGenreSwitcher");
+    cDebug d("TestGenre");
     d.TraceDebug("Entering...\n");
 
-    cGenreSwitcher* genreSwitcher = cGenreSwitcher::GetInstance();
+    TEST(cGenreSwitcher::GetInstance()->StringToGenre(cGenreSwitcher::GetInstance()->GenreToString(cFS::GenreID())) == cFS::GenreID());
 
-    TEST(genreSwitcher->CurrentGenre() == cFS::GenreID());
-    
-    // can't switch to invalid genre
-    //genreSwitcher->SelectGenre(cGenre::GENRE_INVALID);
-    //TEST(genreSwitcher->CurrentGenre() == cGenre::GENRE_INVALID);
+    //TODO: GenreToString() dies w/ GENRE_INVALID. Figure out if this should be changed.
+    //
+    //TEST(cGenreSwitcher::GetInstance()->StringToGenre(cGenreSwitcher::GetInstance()->GenreToString(cGenre::GENRE_INVALID)) == cGenre::GENRE_INVALID);
 
-    genreSwitcher->SelectGenre(cFS::GenreID());
-    TEST(genreSwitcher->CurrentGenre() == cFS::GenreID());
-    TEST(typeid(*iTWFactory::GetInstance()) == typeid(cFSFactory));
+
+    TEST(cGenreSwitcher::GetInstance()->StringToGenre(_T("fs")) == cFS::GenreID());
+    TEST(cGenreSwitcher::GetInstance()->StringToGenre(_T("none of the above")) == cGenre::GENRE_INVALID);
 
     d.TraceDebug("All tests passed.\n");
 }
+
+void RegisterSuite_Genre()
+{
+    RegisterTest("Genre", "Basic", TestGenre);
+}
